searchData={"items":[{"type":"module","title":"SilverOrb","doc":"WebAssembly is low level — you essentially get to define global variables, an array of memory, and some functions to operate on them. It’s not batteries-included.\n\n`SilverOrb` provides several extra batteries so common tasks are easier. They are:\n\n- `SilverOrb.Arena` allocator for memory management.\n- `SilverOrb.ASCII` (coming soon) for operating on ASCII strings.\n- `SilverOrb.UTF8` (coming soon) for operating on UTF-8 strings.\n- `SilverOrb.IntFormatter` for converting integers to strings.\n- `SilverOrb.IntParser` (coming soon) for converting strings to integers.\n- `SilverOrb.StringBuilder` for assembling strings from dynamic parts.\n- `SilverOrb.XMLBuilder` (coming soon) for assembling XML from dynamic parts.\n- `SilverOrb.FormData` (coming soon) for decoding/encoding `application/x-www-form-urlencoded` strings.\n- `SilverOrb.URLSearchParams` (coming soon) for decoding/encoding URL query strings.\n- `SilverOrb.URL` (coming soon) for decoding/encoding URLs.\n- `SilverOrb.Request` (coming soon) for encoding HTTP/1 requests.\n- `SilverOrb.Response` (coming soon) for encoding HTTP/1 responses.\n- `SilverOrb.Iterator` (coming soon) for creating a custom sequence type that can be iterated through.","ref":"SilverOrb.html"},{"type":"module","title":"SilverOrb.ASCII","doc":"","ref":"SilverOrb.ASCII.html"},{"type":"function","title":"SilverOrb.ASCII.funcp/0","doc":"Import all WebAssembly functions from this module’s Orb definition.","ref":"SilverOrb.ASCII.html#funcp/0"},{"type":"function","title":"SilverOrb.ASCII.funcp/1","doc":"Import a specific WebAssembly function from this module’s Orb definition.","ref":"SilverOrb.ASCII.html#funcp/1"},{"type":"function","title":"SilverOrb.ASCII.lowercase/1","doc":"","ref":"SilverOrb.ASCII.html#lowercase/1"},{"type":"function","title":"SilverOrb.ASCII.to_wat/0","doc":"Convert this module’s Orb definition to WebAssembly text (Wat) format.","ref":"SilverOrb.ASCII.html#to_wat/0"},{"type":"function","title":"SilverOrb.ASCII.uppercase8/1","doc":"","ref":"SilverOrb.ASCII.html#uppercase8/1"},{"type":"function","title":"SilverOrb.ASCII.uppercase32/1","doc":"","ref":"SilverOrb.ASCII.html#uppercase32/1"},{"type":"function","title":"SilverOrb.ASCII.uppercase64/1","doc":"","ref":"SilverOrb.ASCII.html#uppercase64/1"},{"type":"function","title":"SilverOrb.ASCII.uppercase/1","doc":"","ref":"SilverOrb.ASCII.html#uppercase/1"},{"type":"module","title":"SilverOrb.Arena","doc":"Arena allocation.\n\nSee https://www.rfleury.com/p/untangling-lifetimes-the-arena-allocator\n\n```elixir\ndefmodule ArenaExample do\n  SilverOrb.Arena.def(First, pages: 2)\n  SilverOrb.Arena.def(Second, pages: 4, max_pages: 10)\n\n  defw example(), a: I32.UnsafePointer, b: I32.UnsafePointer do\n    a = First.alloc(4)\n    Memory.store!(I32, a, 42)\n\n    b = Second.alloc(4)\n    Memory.store!(I32, b, 99)\n\n    assert!(a !== First.alloc(4))\n    First.rewind()\n    assert!(a === First.alloc(4))\n  end\nend\n```","ref":"SilverOrb.Arena.html"},{"type":"macro","title":"SilverOrb.Arena.def/2","doc":"Defines an arena of memory. An Elixir module with your passed `name` is defined with `alloc!/1` and `rewind/0` functions.","ref":"SilverOrb.Arena.html#def/2"},{"type":"macro","title":"Options - SilverOrb.Arena.def/2","doc":"When defining an arena, two options can be given:\n\n- `:pages` — The number of pages to allocate for this arena. The global memory is increased by this count.\n- `:max_pages` — The maxmimum number of pages this can increase the global memory by using `Orb.Memory.grow!/1`. Only the last arena can support `max_pages`, as otherwise multiple arenas each growing in size will end up overlapping.","ref":"SilverOrb.Arena.html#def/2-options"},{"type":"function","title":"SilverOrb.Arena.funcp/0","doc":"Import all WebAssembly functions from this module’s Orb definition.","ref":"SilverOrb.Arena.html#funcp/0"},{"type":"function","title":"SilverOrb.Arena.funcp/1","doc":"Import a specific WebAssembly function from this module’s Orb definition.","ref":"SilverOrb.Arena.html#funcp/1"},{"type":"function","title":"SilverOrb.Arena.to_wat/0","doc":"Convert this module’s Orb definition to WebAssembly text (Wat) format.","ref":"SilverOrb.Arena.html#to_wat/0"},{"type":"module","title":"SilverOrb.BumpAllocator","doc":"A bump allocator for Orb modules.\n\n```elixir\ndefmodule Example do\n  use Orb\n  use SilverOrb.BumpAllocator\n\nend\n```","ref":"SilverOrb.BumpAllocator.html"},{"type":"function","title":"SilverOrb.BumpAllocator.alloc/1","doc":"","ref":"SilverOrb.BumpAllocator.html#alloc/1"},{"type":"macro","title":"SilverOrb.BumpAllocator.export_alloc/0","doc":"","ref":"SilverOrb.BumpAllocator.html#export_alloc/0"},{"type":"function","title":"SilverOrb.BumpAllocator.free_all/0","doc":"","ref":"SilverOrb.BumpAllocator.html#free_all/0"},{"type":"function","title":"SilverOrb.BumpAllocator.funcp/0","doc":"Import all WebAssembly functions from this module’s Orb definition.","ref":"SilverOrb.BumpAllocator.html#funcp/0"},{"type":"function","title":"SilverOrb.BumpAllocator.funcp/1","doc":"Import a specific WebAssembly function from this module’s Orb definition.","ref":"SilverOrb.BumpAllocator.html#funcp/1"},{"type":"function","title":"SilverOrb.BumpAllocator.to_wat/0","doc":"Convert this module’s Orb definition to WebAssembly text (Wat) format.","ref":"SilverOrb.BumpAllocator.html#to_wat/0"},{"type":"module","title":"SilverOrb.BumpAllocator.Constants","doc":"","ref":"SilverOrb.BumpAllocator.Constants.html"},{"type":"function","title":"SilverOrb.BumpAllocator.Constants.bump_init_offset/0","doc":"","ref":"SilverOrb.BumpAllocator.Constants.html#bump_init_offset/0"},{"type":"module","title":"SilverOrb.IntFormatter","doc":"","ref":"SilverOrb.IntFormatter.html"},{"type":"function","title":"SilverOrb.IntFormatter.format_u32/2","doc":"","ref":"SilverOrb.IntFormatter.html#format_u32/2"},{"type":"function","title":"SilverOrb.IntFormatter.format_u32_char_count/1","doc":"","ref":"SilverOrb.IntFormatter.html#format_u32_char_count/1"},{"type":"function","title":"SilverOrb.IntFormatter.funcp/0","doc":"Import all WebAssembly functions from this module’s Orb definition.","ref":"SilverOrb.IntFormatter.html#funcp/0"},{"type":"function","title":"SilverOrb.IntFormatter.funcp/1","doc":"Import a specific WebAssembly function from this module’s Orb definition.","ref":"SilverOrb.IntFormatter.html#funcp/1"},{"type":"function","title":"SilverOrb.IntFormatter.to_wat/0","doc":"Convert this module’s Orb definition to WebAssembly text (Wat) format.","ref":"SilverOrb.IntFormatter.html#to_wat/0"},{"type":"module","title":"SilverOrb.Mem","doc":"memcpy and memset for Orb.\n\n```elixir\ndefmodule Example do\n  use Orb\n  use SilverOrb.Mem\n\nend\n```","ref":"SilverOrb.Mem.html"},{"type":"function","title":"SilverOrb.Mem.funcp/0","doc":"Import all WebAssembly functions from this module’s Orb definition.","ref":"SilverOrb.Mem.html#funcp/0"},{"type":"function","title":"SilverOrb.Mem.funcp/1","doc":"Import a specific WebAssembly function from this module’s Orb definition.","ref":"SilverOrb.Mem.html#funcp/1"},{"type":"function","title":"SilverOrb.Mem.memcpy/1","doc":"","ref":"SilverOrb.Mem.html#memcpy/1"},{"type":"function","title":"SilverOrb.Mem.memcpy/3","doc":"","ref":"SilverOrb.Mem.html#memcpy/3"},{"type":"function","title":"SilverOrb.Mem.memset/1","doc":"","ref":"SilverOrb.Mem.html#memset/1"},{"type":"function","title":"SilverOrb.Mem.to_wat/0","doc":"Convert this module’s Orb definition to WebAssembly text (Wat) format.","ref":"SilverOrb.Mem.html#to_wat/0"},{"type":"module","title":"SilverOrb.StringBuilder","doc":"Build strings with dynamic content.\n\n```elixir\ndefmodule MultiStepForm do\n  use Orb\n  use I32.String\n  use SilverOrb.BumpAllocator\n  use SilverOrb.StringBuilder\n\n  global do\n    @step 1\n  end\n\n  global :export_mutable do\n    @step_count 4\n  end\n\n  defw(get_current_step(), I32, do: @step)\n\n  defwp change_step(step: I32) do\n    @step =\n      if step   @step_count, do: @step_count, else: step)\n      end\n  end\n\n  defw(next_step(), do: change_step(@step + 1))\n  defw(previous_step(), do: change_step(@step - 1))\n  defw(jump_to_step(step: I32), do: change_step(step))\n\n  defw(to_string(), I32.String, do: to_html())\n\n  defw to_html(), I32.String do\n    build! do\n      build_step(1)\n      build_step(2)\n      build_step(3)\n      build_step(4)\n      build_step(5)\n    end\n  end\n\n  defwp build_step(step: I32), I32.String, current_step?: I32 do\n    current_step? = step === Orb.Instruction.global_get(:i32, :step)\n\n    build! do\n      ~S[ ]\n      append!(decimal_u32: step)\n      ~S[ \\n]\n    end\n  end\nend\n```","ref":"SilverOrb.StringBuilder.html"},{"type":"function","title":"SilverOrb.StringBuilder.append!/1","doc":"","ref":"SilverOrb.StringBuilder.html#append!/1"},{"type":"function","title":"SilverOrb.StringBuilder.append!/2","doc":"","ref":"SilverOrb.StringBuilder.html#append!/2"},{"type":"function","title":"SilverOrb.StringBuilder.append!/3","doc":"","ref":"SilverOrb.StringBuilder.html#append!/3"},{"type":"function","title":"SilverOrb.StringBuilder.append!/4","doc":"","ref":"SilverOrb.StringBuilder.html#append!/4"},{"type":"function","title":"SilverOrb.StringBuilder.appended?/0","doc":"","ref":"SilverOrb.StringBuilder.html#appended?/0"},{"type":"macro","title":"SilverOrb.StringBuilder.build!/1","doc":"","ref":"SilverOrb.StringBuilder.html#build!/1"},{"type":"function","title":"SilverOrb.StringBuilder.build_begin!/0","doc":"","ref":"SilverOrb.StringBuilder.html#build_begin!/0"},{"type":"function","title":"SilverOrb.StringBuilder.build_done!/0","doc":"","ref":"SilverOrb.StringBuilder.html#build_done!/0"},{"type":"function","title":"SilverOrb.StringBuilder.build_item/1","doc":"","ref":"SilverOrb.StringBuilder.html#build_item/1"},{"type":"function","title":"SilverOrb.StringBuilder.funcp/0","doc":"Import all WebAssembly functions from this module’s Orb definition.","ref":"SilverOrb.StringBuilder.html#funcp/0"},{"type":"function","title":"SilverOrb.StringBuilder.funcp/1","doc":"Import a specific WebAssembly function from this module’s Orb definition.","ref":"SilverOrb.StringBuilder.html#funcp/1"},{"type":"function","title":"SilverOrb.StringBuilder.to_wat/0","doc":"Convert this module’s Orb definition to WebAssembly text (Wat) format.","ref":"SilverOrb.StringBuilder.html#to_wat/0"},{"type":"module","title":"SilverOrb.StringBuilder.DSL","doc":"","ref":"SilverOrb.StringBuilder.DSL.html"},{"type":"macro","title":"SilverOrb.StringBuilder.DSL.if/2","doc":"","ref":"SilverOrb.StringBuilder.DSL.html#if/2"},{"type":"extras","title":"SilverOrb","doc":"# SilverOrb\n\nA standard library for Orb.\n\nThe docs can be found at  .\n\nWebAssembly is low level — you essentially get to define global variables, an array of memory, and some functions to operate on them. It’s not batteries-included.\n\nSilverOrb provides several extra batteries so common tasks are easier. They are:\n\n- `Arena` allocator for memory management.\n- `ASCII` (coming soon) for operating on ASCII strings.\n- `UTF8` (coming soon) for operating on UTF-8 strings.\n- `IntFormatter` for converting integers to strings.\n- `IntParser` (coming soon) for converting strings to integers.\n- `StringBuilder` for assembling strings from dynamic parts.\n- `XMLBuilder` (coming soon) for assembling XML from dynamic parts.\n- `FormData` (coming soon) for decoding/encoding `application/x-www-form-urlencoded` strings.\n- `URLSearchParams` (coming soon) for decoding/encoding URL query strings.\n- `URL` (coming soon) for decoding/encoding URLs.\n- `Request` (coming soon) for encoding HTTP/1 requests.\n- `Response` (coming soon) for encoding HTTP/1 responses.\n- `Iterator` (coming soon) for creating a custom sequence type that can be iterated through.","ref":"readme.html"},{"type":"extras","title":"Installation - SilverOrb","doc":"The package can be installed by adding `silver_orb` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:silver_orb, \"~> 0.0.6\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Inspiration - SilverOrb","doc":"- https://www.rfleury.com/p/untangling-lifetimes-the-arena-allocator","ref":"readme.html#inspiration"}],"content_type":"text/markdown"}